<?php

namespace Drupal\pid_field_set\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'pid_field_set' field type.
 *
 * @FieldType(
 *   id = "pid_field_set",
 *   module = "pid_field_set",
 *   label = @Translation("Pid Field Set"),
 *   category = @Translation("General"),
 *   description = @Translation("A set of persistent identifiers."),
 *   default_widget = "pid_field_set_widget",
 *   default_formatter = "pid_field_set_default",
 *   cardinality = 1
 * )
 *
**/

class PidFieldSetFieldItem extends FieldItemBase {
    /**
    * {@inheritdoc}
    */
    public static function schema(FieldStorageDefinitionInterface $field) {

      $columns = [
        'pid_type' => [
          'type' => 'varchar',
          'length' => 1024,

        ],
        'persistent_item' => [
          'type' => 'varchar',
          'length' => 1024,

        ],
        'persistent_item_root' => [
          'type' => 'varchar',
          'length' => 1024,

        ],
        'persistent_item_parent' => [
          'type' => 'varchar',
          'length' => 1024,

        ],
        'pid_url' => [
          'type' => 'varchar',
          'length' => 2048,

        ],
        'url_prefix' => [
          'type' => 'varchar',
          'length' => 2048,

        ],
      ];
      $schema = [
        'columns' => $columns,
        // @DCG Add indexes here if necessary.
      ];

      return $schema;
    }

    /**
    * {@inheritdoc}
    */
    public function isEmpty() {
      if ($this->persistent_item !== NULL && $this->persistent_item !== '') {
        return FALSE;
      }
      return TRUE;
    }


    /**
    * {@inheritdoc}
    */
    public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
      $properties['pid_type'] = DataDefinition::create('string')
        ->setLabel(t('Persistent Id Type'));
      $properties['persistent_item_root'] = DataDefinition::create('string')
        ->setLabel(t('Persistent Field Root Id'));
      $properties['persistent_item_parent'] = DataDefinition::create('string')
        ->setLabel(t('Persistent Field Parent Id'));
      $properties['persistent_item'] = DataDefinition::create('string')
        ->setLabel(t('Persistent Field Id'));
      $properties['pid_url'] = DataDefinition::create('string')
        ->setLabel(t('Persistent Id URL'));
      $properties['url_prefix'] = DataDefinition::create('string')
        ->setLabel(t('Persistent Id URL Prefix'));
      return $properties;
    }

  /**
   * {@inheritdoc}
  */
  public function getConstraints() {
    $constraints = parent::getConstraints();

    return $constraints;
  }

}

